//管理员
import {PropCookie} from "./account/PropCookie";


export interface ManagerEntity {
    managerId:string;
}


/**
 * 用户信息
 */
export interface UserEntity{
    //用户ID
    userId:string;
    //用户姓名
    name:string;
    //用户年龄
    age:number;
    //用户电话
    mobile:string;
    //用户邮箱
    email:string;
    //住址
    address:string;
    //服务地点
    serviceAddress:string;
    //个人简介
    info:string;
    //头像
    headImg?:string;
    //性别
    sex:string;
    //身份
    userType:string;
    //用户状态
    chatStatus?:boolean;
    //是否我的好友
    isMyFriend?:boolean;
    //时间币
    timeScore?:boolean;
    //头像文件
    activityImgFile?:any;
}

//活动
export interface ActiveForm {
    title:string;
    content:string;
}

/**
 * 文本输入框组件封装
 */
export interface FormInputProps {
    //表单名
    name: string
    //描述信息
    desc: string
    //提示信息
    placeholder?: string
    //表单值
    value?: string
    //数据类型
    type?:
        | "text"
        | "password"
        | "number"
    as?: React.ElementType;
    //值改变事件
    onChange?: Function
    //验证信息
    valid?: {
        check?: Boolean;
        valid?: String;
        invalid?: String;
    }
    //长度
    maxLength?: number
    //选项
    options?:Array<JSX.Element>;
    //bootstrap col
    col?: number
    //整体样式，若存在会覆盖col局部样式
    className?:string;
}

/**
 * 注册表单
 */
export interface RegisterProps {
    //跳转登录
    toLogin: Function;
}

/**
 * 弹框提示
 */
export interface Tip {
    tipContent:JSX.Element|null;
}

/**
 * 注册状态
 */
export interface RegisterState extends Tip{
    managerId:string;
    //密码
    password: string;
    //确认密码
    confirmPwd: string;
}

/**
 * 登陆表单
 */
export interface LoginProps extends PropCookie {
    //跳转注册
    toRegister: Function;
    //注册成功回调
    onLoginSuccess: Function;
}

/**
 * 登陆表单
 */
export interface LoginState extends Tip{
    //管理员名
    managerId: string;
    //密码
    password: string;
}

export interface BaseDialogProps {
    //弹窗名
    menuName:string;
    //关闭事件
    onClose:Function;
}
export interface CloseDialogProps extends BaseDialogProps{
    //
    titleId:string;
}
/**
 * 我的弹窗
 */
export interface MyDialogProps extends CloseDialogProps{
    //弹窗内容
    content:JSX.Element|null;
    //弹窗状态
    open:boolean;
    //窗口宽度
    maxWidth?:number;
}

/**
 * 分页信息
 */
export interface PageProps{
    //当前页
    currentPage:number;
    //总页数
    totalPage:number;
    //分页大小
    pageSize:number;
}

/**
 * 分页点击
 */
export interface PageClickProps extends PageProps{
    //分页点击事件
    onClick:Function;
}

export enum UserType {
    seekHelp="seekHelp",
    help="help"
}
//活动列表
export interface ManagerActivity {
    activityId:number;
    content:string;
    title:string;
    activityImg:string;
    activityStartTime:number;
    activityEndTime:number;
    seekHelpUser:number;
    helpUser:Array<string>;
    activityImgFile?:any;
}

/**
 * 地点信息
 */
export interface AddressProps {
    address:string;
}

export interface OnChangeAddress {
    onChange:Function;
    col?:number;
    value?:string;
    className?:string;
}

export interface TimeScore {
    createTime:number;
    timeScore:number;
}

